@@ -18,13 +18,5 @@
 translate.dcf <- function(filename)
 {
   settings <- read.dcf(filename)
-
-  tmp <- list()
-
-  for (name in colnames(settings))
-  {
-    tmp[[name]] <- as.character(settings[1, name])
-  }
-
-  return(tmp)
+  setNames(as.list(as.character(settings)), colnames(settings))
 }
